==> cargo-binstall-1.15.7-1.src.tar.gz: cargo-binstall-1.15.7/crates/fs-lock/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.11](https://github.com/cargo-bins/cargo-binstall/compare/fs-lock-v0.1.10...fs-lock-v0.1.11) - 2025-08-09

### Other

- Use newly stablised stdlib file lock API ([#2254](https://github.com/cargo-bins/cargo-binstall/pull/2254))
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.10](https://github.com/cargo-bins/cargo-binstall/compare/fs-lock-v0.1.9...fs-lock-v0.1.10) - 2025-03-19

### Fixed

- actually check if lock was acquired ([#2091](https://github.com/cargo-bins/cargo-binstall/pull/2091))

## [0.1.9](https://github.com/cargo-bins/cargo-binstall/compare/fs-lock-v0.1.8...fs-lock-v0.1.9) - 2025-03-07

### Other

- *(deps)* bump the deps group with 3 updates ([#2072](https://github.com/cargo-bins/cargo-binstall/pull/2072))

## [0.1.8](https://github.com/cargo-bins/cargo-binstall/compare/fs-lock-v0.1.7...fs-lock-v0.1.8) - 2025-02-22

### Other

- Log when FileLock::drop fails to unlock file ([#2064](https://github.com/cargo-bins/cargo-binstall/pull/2064))
- Fix fs-lock error on nightly ([#2059](https://github.com/cargo-bins/cargo-binstall/pull/2059))

## [0.1.7](https://github.com/cargo-bins/cargo-binstall/compare/fs-lock-v0.1.6...fs-lock-v0.1.7) - 2024-12-07

### Other

- *(deps)* bump the deps group with 3 updates ([#1993](https://github.com/cargo-bins/cargo-binstall/pull/1993))

## [0.1.6](https://github.com/cargo-bins/cargo-binstall/compare/fs-lock-v0.1.5...fs-lock-v0.1.6) - 2024-11-05

### Other

- *(deps)* bump the deps group with 3 updates ([#1954](https://github.com/cargo-bins/cargo-binstall/pull/1954))

## [0.1.5](https://github.com/cargo-bins/cargo-binstall/compare/fs-lock-v0.1.4...fs-lock-v0.1.5) - 2024-10-12

### Other

- *(deps)* bump fs4 from 0.9.1 to 0.10.0 in the deps group ([#1929](https://github.com/cargo-bins/cargo-binstall/pull/1929))

## [0.1.4](https://github.com/cargo-bins/cargo-binstall/compare/fs-lock-v0.1.3...fs-lock-v0.1.4) - 2024-08-04

### Other
- *(deps)* bump the deps group across 1 directory with 2 updates ([#1859](https://github.com/cargo-bins/cargo-binstall/pull/1859))

==> cargo-binstall-1.15.10-1.src.tar.gz: cargo-binstall-1.15.10/crates/fs-lock/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.11](https://github.com/cargo-bins/cargo-binstall/compare/fs-lock-v0.1.10...fs-lock-v0.1.11) - 2025-08-09

### Other

- Use newly stablised stdlib file lock API ([#2254](https://github.com/cargo-bins/cargo-binstall/pull/2254))
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.13](https://github.com/cargo-bins/cargo-binstall/compare/fs-lock-v0.1.12...fs-lock-v0.1.13) - 2025-11-02

### Other

- Fix fs-lock: pull in fs4 for Illumos ([#2350](https://github.com/cargo-bins/cargo-binstall/pull/2350))

## [0.1.12](https://github.com/cargo-bins/cargo-binstall/compare/fs-lock-v0.1.11...fs-lock-v0.1.12) - 2025-11-01

### Other

- Fix `fs-lock` for android ([#2348](https://github.com/cargo-bins/cargo-binstall/pull/2348))

## [0.1.10](https://github.com/cargo-bins/cargo-binstall/compare/fs-lock-v0.1.9...fs-lock-v0.1.10) - 2025-03-19

### Fixed

- actually check if lock was acquired ([#2091](https://github.com/cargo-bins/cargo-binstall/pull/2091))

## [0.1.9](https://github.com/cargo-bins/cargo-binstall/compare/fs-lock-v0.1.8...fs-lock-v0.1.9) - 2025-03-07

### Other

- *(deps)* bump the deps group with 3 updates ([#2072](https://github.com/cargo-bins/cargo-binstall/pull/2072))

## [0.1.8](https://github.com/cargo-bins/cargo-binstall/compare/fs-lock-v0.1.7...fs-lock-v0.1.8) - 2025-02-22

### Other

- Log when FileLock::drop fails to unlock file ([#2064](https://github.com/cargo-bins/cargo-binstall/pull/2064))
- Fix fs-lock error on nightly ([#2059](https://github.com/cargo-bins/cargo-binstall/pull/2059))

## [0.1.7](https://github.com/cargo-bins/cargo-binstall/compare/fs-lock-v0.1.6...fs-lock-v0.1.7) - 2024-12-07

### Other

- *(deps)* bump the deps group with 3 updates ([#1993](https://github.com/cargo-bins/cargo-binstall/pull/1993))

## [0.1.6](https://github.com/cargo-bins/cargo-binstall/compare/fs-lock-v0.1.5...fs-lock-v0.1.6) - 2024-11-05

### Other

- *(deps)* bump the deps group with 3 updates ([#1954](https://github.com/cargo-bins/cargo-binstall/pull/1954))

## [0.1.5](https://github.com/cargo-bins/cargo-binstall/compare/fs-lock-v0.1.4...fs-lock-v0.1.5) - 2024-10-12

### Other

- *(deps)* bump fs4 from 0.9.1 to 0.10.0 in the deps group ([#1929](https://github.com/cargo-bins/cargo-binstall/pull/1929))

## [0.1.4](https://github.com/cargo-bins/cargo-binstall/compare/fs-lock-v0.1.3...fs-lock-v0.1.4) - 2024-08-04

### Other
- *(deps)* bump the deps group across 1 directory with 2 updates ([#1859](https://github.com/cargo-bins/cargo-binstall/pull/1859))
